# Generated by Django 5.2.15 on 2026-06-15 19:30

import fitcheck.models.doctrine
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0014_alter_assignmentitempolicy_section_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assignmentitempolicy',
            name='allowed_meta_groups',
            field=models.JSONField(blank=True, default=fitcheck.models.doctrine.default_allowed_meta_groups),
        ),
        migrations.AlterField(
            model_name='doctrinefititem',
            name='allowed_meta_groups',
            field=models.JSONField(blank=True, default=fitcheck.models.doctrine.default_allowed_meta_groups, help_text='Meta group IDs allowed as substitutes (checked = allowed). Empty = no family substitutes.'),
        ),
    ]
