# Generated by Django 5.2.15 on 2026-06-17 22:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0023_compliancepolicy_disabled_at'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assignmentitempolicy',
            name='policy',
            field=models.CharField(choices=[('EX', 'Strict (exact type only)'), ('VA', 'Standard (variant family)'), ('MB', 'Flexible (meets or beats attributes)'), ('AN', 'No enforcement (anything accepted)')], max_length=2),
        ),
        migrations.AlterField(
            model_name='doctrinefit',
            name='default_policy',
            field=models.CharField(choices=[('EX', 'Strict (exact type only)'), ('VA', 'Standard (variant family)'), ('MB', 'Flexible (meets or beats attributes)'), ('AN', 'No enforcement (anything accepted)')], default='VA', max_length=2),
        ),
        migrations.AlterField(
            model_name='doctrinefititem',
            name='policy',
            field=models.CharField(choices=[('EX', 'Strict (exact type only)'), ('VA', 'Standard (variant family)'), ('MB', 'Flexible (meets or beats attributes)'), ('AN', 'No enforcement (anything accepted)')], max_length=2),
        ),
    ]
