# Generated by Django 5.2.15 on 2026-06-15 14:12

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0025_remove_evecharacter_last_updated_and_more'),
        ('eveuniverse', '0012_alter_evebloodline_eve_ship_type'),
        ('fitcheck', '0011_backfill_assignments'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name='fitsubmission',
            name='doctrine',
            field=models.ForeignKey(blank=True, help_text="Doctrine whose policy snapshot this submission was graded against. Empty = graded against the fit's source-level defaults.", null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='fitcheck.doctrine'),
        ),
        migrations.AddIndex(
            model_name='fitsubmission',
            index=models.Index(fields=['doctrine', 'status'], name='fitcheck_fi_doctrin_902e82_idx'),
        ),
    ]
