# Generated by Django 5.2.15 on 2026-06-16 21:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0019_alter_assignmentitempolicy_section_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='EnforcementSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('implant_mode', models.CharField(choices=[('REJECT', 'Reject - Always Enforce'), ('POLICY', 'Enforce by policy'), ('WARN', 'Pass - Warning'), ('IGNORE', 'Pass - Never Enforce')], default='POLICY', max_length=6)),
                ('fuel_mode', models.CharField(choices=[('REJECT', 'Reject - Always Enforce'), ('POLICY', 'Enforce by policy'), ('WARN', 'Pass - Warning'), ('IGNORE', 'Pass - Never Enforce')], default='WARN', max_length=6)),
                ('booster_mode', models.CharField(choices=[('REJECT', 'Reject - Always Enforce'), ('POLICY', 'Enforce by policy'), ('WARN', 'Pass - Warning'), ('IGNORE', 'Pass - Never Enforce')], default='WARN', max_length=6)),
                ('feb_mode', models.CharField(choices=[('REJECT', 'Reject - Always Enforce'), ('POLICY', 'Enforce by policy'), ('WARN', 'Pass - Warning'), ('IGNORE', 'Pass - Never Enforce')], default='IGNORE', max_length=6)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'Enforcement settings',
                'verbose_name_plural': 'Enforcement settings',
            },
        ),
    ]
