# Generated by Django 5.2.15 on 2026-06-18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fitcheck', '0026_fitcompliancefilter'),
    ]

    operations = [
        migrations.AddField(
            model_name='doctrinecategory',
            name='source_plugin_pk',
            field=models.PositiveIntegerField(blank=True, db_index=True, help_text='Primary key of the source Category in the `fittings` plugin, if synced.', null=True),
        ),
    ]
